
## CATO-CLI - query.container.ipAddressRange.testFromURL:
[Click here](https://api.catonetworks.com/documentation/#query-query.container.ipAddressRange.testFromURL) for documentation on this operation.

### Usage for query.container.ipAddressRange.testFromURL:

```bash
catocli query container ipAddressRange testFromURL -h

catocli query container ipAddressRange testFromURL <json>

catocli query container ipAddressRange testFromURL --json-file query.container.ipAddressRange.testFromURL.json

catocli query container ipAddressRange testFromURL '{"testContainerFromUrlInput":{"fileType":"STIX","url":"example_value"}}'

catocli query container ipAddressRange testFromURL '{
    "testContainerFromUrlInput": {
        "fileType": "STIX",
        "url": "example_value"
    }
}'
```

#### Operation Arguments for query.container.ipAddressRange.testFromURL ####

`accountId` [ID] - (required) N/A    
`testContainerFromUrlInput` [TestContainerFromUrlInput] - (required) N/A    
